--- ./bin/yum.py.orig 2006-12-05 09:33:35.000000000 +0100
+++ ./bin/yum.py 2007-06-20 16:22:40.000000000 +0200
""" % (sys.exc_value, sys.version)
-sys.path.insert(0, '/usr/share/yum-cli')
+sys.path.insert(0, '@@PREFIX@@/share/yum-cli')
yummain.main(sys.argv[1:])
--- bin/yum-updatesd.py.orig 2007-07-25 17:05:44.000000000 +0200
+++ bin/yum-updatesd.py 2007-08-28 17:16:06.000000000 +0200
-sys.path.insert(0, '/usr/share/yum-cli')
+sys.path.insert(0, '@@PREFIX@@/share/yum-cli')
--- ./callback.py.orig 2007-02-03 20:49:32.000000000 +0100
+++ ./callback.py 2007-06-19 18:17:13.000000000 +0200
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
--- cli.py.orig 2007-08-15 17:48:03.000000000 +0200
+++ cli.py 2007-08-28 17:08:57.000000000 +0200
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
if os.access(opts.installroot+'/'+opts.conffile, os.R_OK):
opts.conffile = opts.installroot+'/'+opts.conffile
- elif opts.conffile == '/etc/yum/yum.conf':
- # check if /installroot/etc/yum.conf exists.
- if os.access(opts.installroot+'/etc/yum.conf', os.R_OK):
- opts.conffile = opts.installroot+'/etc/yum.conf'
+ elif opts.conffile == '@@PREFIX@@/etc/yum/yum.conf':
+ # check if /installroot/@@PREFIX@@/etc/yum.conf exists.
+ if os.access(opts.installroot+'@@PREFIX@@/etc/yum.conf', os.R_OK):
+ opts.conffile = opts.installroot+'@@PREFIX@@/etc/yum.conf'